@@ -14,16 +14,27 @@
 
 from testtools import testcase as tc
 
+from tempest import config
 from tempest.lib import decorators
 from tempest.lib.common.utils import data_utils
 
 from sahara_tempest_plugin.tests.api import base as dp_base
 
 
+CONF = config.CONF
+
+
 class JobBinaryInternalTest(dp_base.BaseDataProcessingTest):
     # Link to the API documentation is https://developer.openstack.org/
     # api-ref/data-processing/#job-binary-internals
 
+    @classmethod
+    def skip_checks(cls):
+        super(JobBinaryInternalTest, cls).skip_checks()
+        if CONF.data_processing.use_api_v2:
+            raise cls.skipException('Job binaries stored on the internal db '
+                                    'are available only with API v1.1')
+
     @classmethod
     def resource_setup(cls):
         super(JobBinaryInternalTest, cls).resource_setup()
@@ -95,4 +106,4 @@ class JobBinaryInternalTest(dp_base.BaseDataProcessingTest):
 
         # get data of job binary internal by id
         _, data = self.client.get_job_binary_internal_data(binary_id)
-        self.assertEqual(data, self.job_binary_internal_data)
+        self.assertEqual(data.decode("utf-8"), self.job_binary_internal_data)
