@@ -14,15 +14,25 @@
 
 from testtools import testcase as tc
 
+from tempest import config
 from tempest.lib import decorators
 from tempest.lib.common.utils import data_utils
 
 from sahara_tempest_plugin.tests.api import base as dp_base
 
 
+CONF = config.CONF
+
+
 class JobTest(dp_base.BaseDataProcessingTest):
     # NOTE: Link to the API documentation: https://developer.openstack.org/
-    # api-ref/data-processing/#jobs
+    # api-ref/data-processing/v1.1/#jobs
+
+    @classmethod
+    def skip_checks(cls):
+        super(JobTest, cls).skip_checks()
+        if CONF.data_processing.use_api_v2:
+            raise cls.skipException('These tests require API v1.1')
 
     @classmethod
     def resource_setup(cls):
