@@ -60,6 +60,21 @@ SCHEMA = {
                     "type": "string",
                     "minLength": 1
                 },
+                "s3_accesskey": {
+                    "type": "string",
+                },
+                "s3_secretkey": {
+                    "type": "string",
+                },
+                "s3_endpoint": {
+                    "type": "string",
+                },
+                "s3_endpoint_ssl": {
+                    "type": "boolean",
+                },
+                "s3_bucket_path": {
+                    "type": "boolean",
+                },
             },
             "additionalProperties": False
         },
@@ -191,6 +206,9 @@ SCHEMA = {
                                         "minLength": 1
                                     }
                                 },
+                                "boot_from_volume": {
+                                    "type": "boolean"
+                                },
                                 "auto_security_group": {
                                     "type": "boolean"
                                 },
@@ -370,7 +388,8 @@ SCHEMA = {
                                 "properties": {
                                     "type": {
                                         "type": "string",
-                                        "enum": ["swift", "hdfs", "maprfs"]
+                                        "enum": ["swift", "hdfs", "maprfs",
+                                                 "s3"]
                                     },
                                     "source": {
                                         "type": "string"
@@ -384,7 +403,8 @@ SCHEMA = {
                                 "properties": {
                                     "type": {
                                         "type": "string",
-                                        "enum": ["swift", "hdfs", "maprfs"]
+                                        "enum": ["swift", "hdfs", "maprfs",
+                                                 "s3"]
                                     },
                                     "destination": {
                                         "type": "string"
@@ -398,7 +418,7 @@ SCHEMA = {
                                 "properties": {
                                     "type": {
                                         "type": "string",
-                                        "enum": ["swift", "database"]
+                                        "enum": ["swift", "s3", "database"]
                                     },
                                     "source": {
                                         "type": "string"
@@ -414,7 +434,7 @@ SCHEMA = {
                                     "properties": {
                                         "type": {
                                             "type": "string",
-                                            "enum": ["swift", "database"]
+                                            "enum": ["swift", "s3", "database"]
                                         },
                                         "source": {
                                             "type": "string"
